@@ -6,7 +6,7 @@
 //! Add this to your `Cargo.toml`
 //! ```toml
 //! [dependencies]
-//! boticordrs = "0.0.1"
+//! boticordrs = "0.1.0"
 //! ```
 //!
 //! ## Example
@@ -29,7 +29,7 @@
 //!     }
 //! }
 //! ```
-#![doc(html_root_url = "https://docs.rs/boticordrs/0.0.1")]
+#![doc(html_root_url = "https://docs.rs/boticordrs/0.1")]
 
 use reqwest::header::AUTHORIZATION;
 use reqwest::{Client as ReqwestClient, Response};
@@ -81,6 +81,11 @@ impl BoticordClient {
         get(self, url).await
     }
 
+    /// Get information about a specific user.
+    pub async fn get_user_info(&self, user: String) -> Result<UserInformation, BoticordError> {
+        let url = api_url!("/profile/{}", user);
+        get(self, url).await
+    }
 
     /// Get Vec of bot's comments.
     pub async fn get_bot_comments(&self, bot: String) -> Result<Vec<SingleComment>, BoticordError> {
@@ -94,6 +99,19 @@ impl BoticordClient {
         get(self, url).await
     }
 
+    /// Get Vec of user's comments.
+    pub async fn get_user_comments(&self, server: String) -> Result<UserComments, BoticordError> {
+        let url = api_url!("/profile/{}/comments", server);
+        get(self, url).await
+    }
+
+    /// Get Vec of user's bots.
+    pub async fn get_user_bots(&self, user: String) -> Result<Vec<SingleUserBot>, BoticordError> {
+        let url = api_url!("/bots/{}", user);
+        get(self, url).await
+    }
+
+
     /// Post current bot's stats.
     /// # How to set BotStats? (example)
     ///
